==> amavis-ng_0.1.6.6.orig.tar.gz: amavis-ng-0.1.6.6.orig/AMAVIS/AV/Trophie.pm <==
# $Id: Trophie.pm,v 1.1 2002/07/29 01:02:25 bengen Exp $

#
# Module for Trophie daemon
#

package AMAVIS::AV::Trophie;
use strict;

use vars qw($VERSION);
$VERSION='0.1';

use AMAVIS;
use AMAVIS::Logging;
use IO::Socket;

use vars qw(
	    $cfg_trophie_socket
	   );

sub init {
  my $self = shift;
  my $args = shift;
  push @{$$args{'virus_scanners'}}, 'Trophie';

  $cfg_trophie_socket=$AMAVIS::cfg->val('Trophie', 'socket');
  if (! defined $cfg_trophie_socket) {
    writelog($args,LOG_CRIT, __PACKAGE__.": Trophie socket not specified");
    return 0;
  }

  writelog($args,LOG_DEBUG,__PACKAGE__." initialized.\n");
  # Return successfully
  return 1;
}

# Called from AMAVIS.pm. Scanning takes place here.
sub scan {
  my $self = shift;
  my $args = shift;

  my $socket=IO::Socket::UNIX->new(Peer=>$cfg_trophie_socket);
  if (!defined $socket) {
    writelog($args,LOG_CRIT, __PACKAGE__.
	     ": Cannot connect to $cfg_trophie_socket.");
    return 0;
  }

  my $path="$$args{directory}/parts\n";
  $socket->syswrite($path, length($path)) or do {
    writelog($args,LOG_ERR, __PACKAGE__.": Write to socket failed.");
    return 0;
  };

  my $output;
  my $result=$socket->sysread($output, 256);
  unless ($result) {
    writelog($args,LOG_ERR, __PACKAGE__.": Read from socket failed.");
    return 0;
  }
  $socket->close() or do {
    writelog($args,LOG_ERR, __PACKAGE__.": Closing socket failed");
    return 0;
  };

  my @virusname;
  if ($output =~ m/^1/) {
    if ($output =~ m/^1:.*$/) {
      @virusname = ($output =~ m/^1:'?(.*)'?$/g);
    }
    @virusname = (undef)  if !@virusname;  # just in case: make list nonnil
    writelog($args,LOG_DEBUG, __PACKAGE__.
	     ": Virus(es) found.".join(',',@virusname));
    my %uniq;
    foreach my $virus (@virusname) {
      unless($uniq{$virus}++) {
	push @{$$args{'found_viruses'}{'Trophie'}}, $virus;
      }
    }
  } elsif ($output == 0) {
    writelog($args,LOG_DEBUG, __PACKAGE__.": No virusses found");
  } elsif ($output == -1) {
    writelog($args,LOG_ERR,__PACKAGE__.": Unknown virus scanner failure: $output");
    return 0;
  } else {
    writelog($args,LOG_ERR, __PACKAGE__.\
	     ": Virus scanner failure: error code: $output");
    return 0;
  }

  # Return successfully...
  return 1;
}

1;

==> amavis-ng_0.1.6.7.orig.tar.gz: amavis-ng-0.1.6.7.orig/AMAVIS/AV/Trophie.pm <==
# $Id: Trophie.pm,v 1.2 2004/07/28 13:46:40 braeucup Exp $

#
# Module for Trophie daemon
#

package AMAVIS::AV::Trophie;
use strict;

use vars qw($VERSION);
$VERSION='0.1';

use AMAVIS;
use AMAVIS::Logging;
use IO::Socket;

use vars qw(
	    $cfg_trophie_socket
	   );

sub init {
  my $self = shift;
  my $args = shift;
  push @{$$args{'virus_scanners'}}, 'Trophie';

  $cfg_trophie_socket=$AMAVIS::cfg->val('Trophie', 'socket');
  if (! defined $cfg_trophie_socket) {
    writelog($args,LOG_CRIT, __PACKAGE__.": Trophie socket not specified");
    return 0;
  }

  writelog($args,LOG_DEBUG,__PACKAGE__." initialized.\n");
  # Return successfully
  return 1;
}

# Called from AMAVIS.pm. Scanning takes place here.
sub scan {
  my $self = shift;
  my $args = shift;

  my $socket=IO::Socket::UNIX->new(Peer=>$cfg_trophie_socket);
  if (!defined $socket) {
    writelog($args,LOG_CRIT, __PACKAGE__.
	     ": Cannot connect to $cfg_trophie_socket.");
    return 0;
  }

  my $path="$$args{directory}/parts\n";
  $socket->syswrite($path, length($path)) or do {
    writelog($args,LOG_ERR, __PACKAGE__.": Write to socket failed.");
    return 0;
  };

  my $output;
  my $result=$socket->sysread($output, 256);
  unless ($result) {
    writelog($args,LOG_ERR, __PACKAGE__.": Read from socket failed.");
    return 0;
  }
  $socket->close() or do {
    writelog($args,LOG_ERR, __PACKAGE__.": Closing socket failed");
    return 0;
  };

  my @virusname;
  if ($output =~ m/^1/) {
    if ($output =~ m/^1:.*$/) {
      @virusname = ($output =~ m/^1:'?(.*)'?$/g);
    }
    @virusname = (undef)  if !@virusname;  # just in case: make list nonnil
    writelog($args,LOG_DEBUG, __PACKAGE__.
	     ": Virus(es) found.".join(',',@virusname));
    my %uniq;
    foreach my $virus (@virusname) {
      unless($uniq{$virus}++) {
	push @{$$args{'found_viruses'}{'Trophie'}}, $virus;
      }
    }
  } elsif ($output == 0) {
    writelog($args,LOG_DEBUG, __PACKAGE__.": No viruses found");
  } elsif ($output == -1) {
    writelog($args,LOG_ERR,__PACKAGE__.": Unknown virus scanner failure: $output");
    return 0;
  } else {
    writelog($args,LOG_ERR, __PACKAGE__.\
	     ": Virus scanner failure: error code: $output");
    return 0;
  }

  # Return successfully...
  return 1;
}

1;
